@@ -16,7 +16,8 @@ function example(geochronometer,plotdevice,format){
 			       0.0001,0.00004,0.00006,0.00004,0.00005],
 		    "rho":    [0.79,0.31,0.85,0.58,0.65,0.88,0.43,0.74,0.65,0.87],
 		    "(C)":    [],
-		    "(omit)": []
+		    "(omit)": [],
+		    "(comment)": []
 		}
 	    });
 	case 2:
@@ -33,7 +34,8 @@ function example(geochronometer,plotdevice,format){
 			       0.00007,0.00011,0.00007,0.00006,0.00004],
 		    "(rho)":  [],
 		    "(C)":    [],
-		    "(omit)": []
+		    "(omit)": [],
+		    "(comment)": []
 		}
 	    });
 	case 3:
@@ -55,43 +57,46 @@ function example(geochronometer,plotdevice,format){
 		    "(rhoXY)": [],
 		    "(rhoYZ)": [],
 		    "(C)":     [],
-		    "(omit)":  []
+		    "(omit)":  [],
+		    "(comment)": []
 		}		
 	    });
 	case 4:
 	    return({
 		"ierr": 1,
 		"data": {
-		    "X=07/35":  [2.8229,2.6401,1.9623,2.5838,2.2208,4.3988,2.0326],
-		    "err[X]": [0.0044,0.0041,0.0034,0.0049,0.0045,0.0049,0.005],
-		    "Y=06/38":  [0.07022,0.068610,0.062320,0.06805,0.06482,0.084940,0.06321],
-		    "err[Y]": [0.00010,0.000090,0.000090,0.00012,0.00012,0.000080,0.00012],
-		    "Z=04/38":  [0.0011468,0.0010625,0.0007508,0.0010323,
+		    "X=07/35": [2.8229,2.6401,1.9623,2.5838,2.2208,4.3988,2.0326],
+		    "err[X]":  [0.0044,0.0041,0.0034,0.0049,0.0045,0.0049,0.005],
+		    "Y=06/38": [0.07022,0.068610,0.062320,0.06805,0.06482,0.084940,0.06321],
+		    "err[Y]":  [0.00010,0.000090,0.000090,0.00012,0.00012,0.000080,0.00012],
+		    "Z=04/38": [0.0011468,0.0010625,0.0007508,0.0010323,
 				 0.0008678,0.0018790,0.0007820],
-		    "err[Z]": [0.0000020,0.0000018,0.0000016,0.0000022,
-			       0.0000018,0.0000024,0.0000020],
-		    "rhoXY":  [0.90,0.89,0.82,0.90,0.93,0.84,0.79],
-		    "rhoXZ":  [0.59,0.56,0.32,0.55,0.78,0.39,0.40],
-		    "rhoYZ":  [0.82,0.82,0.69,0.79,0.93,0.74,0.79],
-		    "(C)":    [],
-		    "(omit)": []
+		    "err[Z]":  [0.0000020,0.0000018,0.0000016,0.0000022,
+			        0.0000018,0.0000024,0.0000020],
+		    "rhoXY":   [0.90,0.89,0.82,0.90,0.93,0.84,0.79],
+		    "rhoXZ":   [0.59,0.56,0.32,0.55,0.78,0.39,0.40],
+		    "rhoYZ":   [0.82,0.82,0.69,0.79,0.93,0.74,0.79],
+		    "(C)":     [],
+		    "(omit)":  [],
+		    "(comment)": []
 		}
 	    });
 	case 5:
 	    return({
 		"ierr": 1,
 		"data": {
-		    "X=38/06":  [14.24,14.575,16.045,14.695,15.428,11.773,15.821],
-		    "err[X]": [0.020,0.020,0.023,0.025,0.029,0.011,0.031],
-		    "Y=07/06":  [0.29168,0.27921,0.22845,0.2755,0.24861,0.37576,0.23333],
-		    "err[Y]": [0.00020,0.00020,0.00023,0.00023,0.00019,0.00023,0.00035],
-		    "Z=04/06":  [0.016331,0.015486,0.012047,0.01517,0.013388,0.022121,0.012372],
-		    "err[Z]": [0.000016,0.000015,0.000018,0.00002,0.00001,0.000019,0.000019],
-		    "rhoXY":  [0,0,0,0,0,0,0],
-		    "rhoXZ":  [0,0,0,0,0,0,0],
-		    "rhoYZ":  [-0.6,-0.6,-0.6,-0.6,-0.6,-0.6,-0.6],
-		    "(C)":    [],
-		    "(omit)": []
+		    "X=38/06": [14.24,14.575,16.045,14.695,15.428,11.773,15.821],
+		    "err[X]":  [0.020,0.020,0.023,0.025,0.029,0.011,0.031],
+		    "Y=07/06": [0.29168,0.27921,0.22845,0.2755,0.24861,0.37576,0.23333],
+		    "err[Y]":  [0.00020,0.00020,0.00023,0.00023,0.00019,0.00023,0.00035],
+		    "Z=04/06": [0.016331,0.015486,0.012047,0.01517,0.013388,0.022121,0.012372],
+		    "err[Z]":  [0.000016,0.000015,0.000018,0.00002,0.00001,0.000019,0.000019],
+		    "rhoXY":   [0,0,0,0,0,0,0],
+		    "rhoXZ":   [0,0,0,0,0,0,0],
+		    "rhoYZ":   [-0.6,-0.6,-0.6,-0.6,-0.6,-0.6,-0.6],
+		    "(C)":     [],
+		    "(omit)":  [],
+		    "(comment)": []
 		}
 	    });
 	case 6:
@@ -99,88 +104,91 @@ function example(geochronometer,plotdevice,format){
 		"ierr": 1,
 		"data": {
 		    "U=07/35":  [2.8229,2.6401,1.9623,2.5838,2.2208,4.3988,2.0326],
-		    "err[U]": [0.0044,0.0041,0.0034,0.0049,0.0045,0.0049,0.005],
+		    "err[U]":   [0.0044,0.0041,0.0034,0.0049,0.0045,0.0049,0.005],
 		    "V=06/38":  [0.07022,0.068610,0.062320,0.06805,0.06482,0.084940,0.06321],
-		    "err[V]": [0.00010,0.000090,0.000090,0.00012,0.00012,0.000080,0.00012],
+		    "err[V]":   [0.00010,0.000090,0.000090,0.00012,0.00012,0.000080,0.00012],
 		    "W=04/38":  [0.0011468,0.0010625,0.0007508,0.0010323,
 				 0.0008678,0.0018790,0.0007820],
-		    "err[W]": [0.0000020,0.0000018,0.0000016,0.0000022,
-			       0.0000018,0.0000024,0.0000020],
+		    "err[W]":   [0.0000020,0.0000018,0.0000016,0.0000022,
+				 0.0000018,0.0000024,0.0000020],
 		    "X=07/06":  [0.29168,0.27921,0.22845,0.2755,0.24861,0.37576,0.23333],
-		    "err[X]": [0.00020,0.00020,0.00023,0.00023,0.00019,0.00023,0.00035],
+		    "err[X]":   [0.00020,0.00020,0.00023,0.00023,0.00019,0.00023,0.00035],
 		    "Y=04/07":  [0.055989,0.055464,0.052734,0.055064,0.053851,0.05887,0.053024],
-		    "err[Y]": [0.000084,0.000084,0.000119,0.000107,0.000073,0.000078,0.000144],
+		    "err[Y]":   [0.000084,0.000084,0.000119,0.000107,0.000073,0.000078,0.000144],
 		    "Z=04/06":  [0.016331,0.015486,0.012047,0.01517,0.013388,0.022121,0.012372],
-		    "err[Z]": [0.000016,0.000015,0.000018,0.00002,0.00001,0.000019,0.000019],
-		    "(C)":    [],
-		    "(omit)": []
+		    "err[Z]":   [0.000016,0.000015,0.000018,0.00002,0.00001,0.000019,0.000019],
+		    "(C)":      [],
+		    "(omit)":   [],
+		    "(comment)":[]
 		}
 	    });
 	case 7:
 	    return({
 		"ierr": 1,
 		"data": {
-		    "W=07/35": [0.256,1.161,0.261,0.539,0.58,1.551,0.519,0.789,0.283,0.848,
-				0.268,0.179,1.613,2.328,0.261,1.473,3.558,0.168,0.561,0.868],
-		    "err[W]":  [0.015,0.068,0.022,0.047,0.062,0.078,0.031,0.054,0.017,0.065,
-				0.02,0.029,0.099,0.112,0.023,0.072,0.11,0.015,0.042,0.044],
-		    "X=06/38": [0.004,0.01241,0.0039,0.0061,0.0068,0.0155,0.0066,
-				0.0086,0.0037,0.01,0.0038,0.0037,0.01511,0.02101,
-				0.0042,0.01431,0.03268,0.0033,0.0071,0.0102],
-		    "err[X]":  [0.00015,0.00046,0.00027,0.00042,0.00029,0.00051,0.00024,
-				0.00037,0.00013,0.00046,0.00018,0.00016,0.00082,0.00066,
-				0.00025,0.00045,0.00064,0.00016,0.00021,0.00031],
-		    "Y=08/32": [0.001622,0.004495,0.00162,0.007663,0.006565,
-				0.004798,0.003583,0.009571,0.00087,0.002201,
-				0.002695,0.00091,0.001731,0.003091,0.00069,
-				0.005902,0.006654,0.00103,0.001701,0.001951],
-		    "err[Y]":  [0.000085,0.000236,0.000155,0.000746,0.000391,
-				0.000220,0.000187,0.000580,0.000043,0.000143,
-				0.000175,0.000055,0.000133,0.000136,0.000059,
-				0.000261,0.000187,0.000070,0.000070,0.000085],
-		    "Z=32/38": [4.44,5.3,4.19,1.25,1.75,6.43,3.15,1.68,14.97,10.77,2.34,
-				17.32,26.71,16.04,50.7,5.09,10.51,7.21,10.02,12.24],
+		    "W=07/35":  [0.256,1.161,0.261,0.539,0.58,1.551,0.519,0.789,0.283,0.848,
+				 0.268,0.179,1.613,2.328,0.261,1.473,3.558,0.168,0.561,0.868],
+		    "err[W]":   [0.015,0.068,0.022,0.047,0.062,0.078,0.031,0.054,0.017,0.065,
+				 0.02,0.029,0.099,0.112,0.023,0.072,0.11,0.015,0.042,0.044],
+		    "X=06/38":  [0.004,0.01241,0.0039,0.0061,0.0068,0.0155,0.0066,
+				 0.0086,0.0037,0.01,0.0038,0.0037,0.01511,0.02101,
+				 0.0042,0.01431,0.03268,0.0033,0.0071,0.0102],
+		    "err[X]":   [0.00015,0.00046,0.00027,0.00042,0.00029,0.00051,0.00024,
+				 0.00037,0.00013,0.00046,0.00018,0.00016,0.00082,0.00066,
+				 0.00025,0.00045,0.00064,0.00016,0.00021,0.00031],
+		    "Y=08/32":  [0.001622,0.004495,0.00162,0.007663,0.006565,
+				 0.004798,0.003583,0.009571,0.00087,0.002201,
+				 0.002695,0.00091,0.001731,0.003091,0.00069,
+				 0.005902,0.006654,0.00103,0.001701,0.001951],
+		    "err[Y]":   [0.000085,0.000236,0.000155,0.000746,0.000391,
+				 0.000220,0.000187,0.000580,0.000043,0.000143,
+				 0.000175,0.000055,0.000133,0.000136,0.000059,
+				 0.000261,0.000187,0.000070,0.000070,0.000085],
+		    "Z=32/38":  [4.44,5.3,4.19,1.25,1.75,6.43,3.15,1.68,14.97,10.77,2.34,
+				 17.32,26.71,16.04,50.7,5.09,10.51,7.21,10.02,12.24],
 		    "(err[Z])": [],
-		    "(rhoWX)": [0.62,0.63,0.81,0.79,0.39,0.65,0.62,0.63,0.58,0.6,
-				0.6,0.27,0.89,0.66,0.69,0.64,0.63,0.53,0.38,0.6],
-		    "(rhoWY)": [0.44,0.45,0.57,0.56,0.28,0.46,0.44,0.45,0.41,0.42,
-				0.43,0.19,0.63,0.47,0.49,0.46,0.44,0.38,0.27,0.42],
-		    "(rhoWZ)": [],
-		    "(rhoXY)": [0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,
-				0.71,0.71,0.71,0.71,0.71,0.71,0.7,0.71,0.71,0.7],
-		    "(rhoXZ)": [],
-		    "(rhoYZ)": [],
-		    "(C)":     [],
-		    "(omit)":  []
+		    "(rhoWX)":  [0.62,0.63,0.81,0.79,0.39,0.65,0.62,0.63,0.58,0.6,
+				 0.6,0.27,0.89,0.66,0.69,0.64,0.63,0.53,0.38,0.6],
+		    "(rhoWY)":  [0.44,0.45,0.57,0.56,0.28,0.46,0.44,0.45,0.41,0.42,
+				 0.43,0.19,0.63,0.47,0.49,0.46,0.44,0.38,0.27,0.42],
+		    "(rhoWZ)":  [],
+		    "(rhoXY)":  [0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,
+				 0.71,0.71,0.71,0.71,0.71,0.71,0.7,0.71,0.71,0.7],
+		    "(rhoXZ)":  [],
+		    "(rhoYZ)":  [],
+		    "(C)":      [],
+		    "(omit)":   [],
+		    "(comment)":[]
 		}
 	    });
 	case 8:
 	    return({
 		"ierr": 1,
 		"data": {
-		    "W=38/06": [250,80.6,256.4,163.9,147.1,64.5,151.5,116.3,270.3,100,
-				263.2,270.3,66.2,47.6,238.1,69.9,30.6,303,140.8,98],
-		    "err[W]":  [9.3,3,17.4,11.3,6.2,2.1,5.6,5,9.5,4.6,
-				12.1,11.6,3.6,1.5,14.3,2.2,0.6,14.5,4.1,3],
-		    "X=07/06": [0.464,0.679,0.485,0.641,0.619,0.726,0.571,0.666,0.554,0.615,
-				0.511,0.35,0.775,0.804,0.45,0.747,0.79,0.37,0.573,0.617],
-		    "err[X]":  [0.022,0.031,0.024,0.034,0.061,0.028,0.027,0.035,0.027,0.038,
-				0.031,0.054,0.022,0.029,0.028,0.028,0.019,0.028,0.04,0.025],
-		    "Y=08/06": [1.8,1.92,1.74,1.57,1.69,1.99,1.71,1.87,3.52,2.37,
-				1.66,4.26,3.06,2.36,8.33,2.1,2.14,2.25,2.4,2.34],
-		    "err[Y]":  [0.067,0.071,0.118,0.108,0.071,0.064,0.063,0.08,0.123,0.109,
-				0.076,0.183,0.165,0.073,0.5,0.065,0.043,0.108,0.07,0.073],
-		    "Z=32/38": [4.44,5.3,4.19,1.25,1.75,6.43,3.15,1.68,14.97,10.77,2.34,
-				17.32,26.71,16.04,50.7,5.09,10.51,7.21,10.02,12.24],
+		    "W=38/06":  [250,80.6,256.4,163.9,147.1,64.5,151.5,116.3,270.3,100,
+				 263.2,270.3,66.2,47.6,238.1,69.9,30.6,303,140.8,98],
+		    "err[W]":   [9.3,3,17.4,11.3,6.2,2.1,5.6,5,9.5,4.6,
+				 12.1,11.6,3.6,1.5,14.3,2.2,0.6,14.5,4.1,3],
+		    "X=07/06":  [0.464,0.679,0.485,0.641,0.619,0.726,0.571,0.666,0.554,0.615,
+				 0.511,0.35,0.775,0.804,0.45,0.747,0.79,0.37,0.573,0.617],
+		    "err[X]":   [0.022,0.031,0.024,0.034,0.061,0.028,0.027,0.035,0.027,0.038,
+				 0.031,0.054,0.022,0.029,0.028,0.028,0.019,0.028,0.04,0.025],
+		    "Y=08/06":  [1.8,1.92,1.74,1.57,1.69,1.99,1.71,1.87,3.52,2.37,
+				 1.66,4.26,3.06,2.36,8.33,2.1,2.14,2.25,2.4,2.34],
+		    "err[Y]":   [0.067,0.071,0.118,0.108,0.071,0.064,0.063,0.08,0.123,0.109,
+			 	 0.076,0.183,0.165,0.073,0.5,0.065,0.043,0.108,0.07,0.073],
+		    "Z=32/38":  [4.44,5.3,4.19,1.25,1.75,6.43,3.15,1.68,14.97,10.77,2.34,
+				 17.32,26.71,16.04,50.7,5.09,10.51,7.21,10.02,12.24],
 		    "(err[Z])": [],
-		    "(rhoWX)": [],
-		    "(rhoWY)": [],
-		    "(rhoWZ)": [],
-		    "(rhoXY)": [],
-		    "(rhoXZ)": [],
-		    "(rhoYZ)": [],
-		    "(C)":     [],
-		    "(omit)":  []
+		    "(rhoWX)":  [],
+		    "(rhoWY)":  [],
+		    "(rhoWZ)":  [],
+		    "(rhoXY)":  [],
+		    "(rhoXZ)":  [],
+		    "(rhoYZ)":  [],
+		    "(C)":      [],
+		    "(omit)":   [],
+		    "(comment)":[]
 		}
 	    });
 	}
@@ -201,7 +209,8 @@ function example(geochronometer,plotdevice,format){
 		    "rho":      [0.9994,0.9999,0.9998,0.9999,0.9999,0.99998,0.9994,0.9999,0.9999,
 				 0.9992,0.9999,0.9994,0.9999,0.99999,0.99999,0.99998,0.99999,0.9949],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)":[]
 		}
 	    });
 	case 2:
@@ -223,7 +232,8 @@ function example(geochronometer,plotdevice,format){
 		    "(rho)":    [0.848,0.967,0.909,0.919,0.975,0.989,0.855,0.982,0.946,
 				 0.804,0.986,0.898,0.49,0.86,0.985,0.975,0.943,0.796],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)":[]
 		}
 	    });
 	case 3:
@@ -256,7 +266,8 @@ function example(geochronometer,plotdevice,format){
 				 0.0011674,0.0004175,0.0002001,0.0003269,0.0012188,
 				 0.0007483,0.0005002,0.0003133],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)": []
 		}		
 	    });
 	}
@@ -277,7 +288,8 @@ function example(geochronometer,plotdevice,format){
 		    "rho": [0.36,0.52,0.42,0.42,0.52,0.55,0.55,0.34,0.58,
 			    0.47,0.73,0.52,0.52,0.53,0.55,0.55,0.49,0.63],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)": []
 		}
 	    });
 	case 2:
@@ -297,7 +309,8 @@ function example(geochronometer,plotdevice,format){
 				   0.00029,0.00031,0.00032,0.00033,0.00028,0.00041],
 		    "(rho)": [],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)": []
 		}
 	    });
 	case 3:
@@ -320,7 +333,8 @@ function example(geochronometer,plotdevice,format){
 		    "err[32/04]": [52,43,44,46,44,43,40,85,38,
 				   56,50,85,50,45,46,30,23,33],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)": []
 		}
 	    });
 	}
@@ -344,7 +358,8 @@ function example(geochronometer,plotdevice,format){
 		    "(39)":       [0.042, 0.094, 0.282, 0.185, 0.27, 0.707,
 				   0.719, 0.479, 0.5, 0.633, 0.405],
 		    "(C)":        [],
-		    "(omit)":     []
+		    "(omit)":     [],
+		    "(comment)": []
 		}
 	    });
 	case 2:
@@ -364,7 +379,8 @@ function example(geochronometer,plotdevice,format){
 		    "(39)":       [0.042, 0.094, 0.282, 0.185, 0.27, 0.707,
 				   0.719, 0.479, 0.5, 0.633, 0.405],
 		    "(C)":        [],
-		    "(omit)":     []
+		    "(omit)":     [],
+		    "(comment)": []
 		}
 	    });
 	case 3:
@@ -394,7 +410,8 @@ function example(geochronometer,plotdevice,format){
 				   0.2702872,0.7072563,0.7188705,0.4792595,
 				   0.5001037,0.6326591,0.4050682],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)": []
 		}
 	    });
 	}
@@ -429,7 +446,8 @@ function example(geochronometer,plotdevice,format){
 				       0.896,0.905,0.907,0.908,0.907,0.903,0.909,0.897,
 				       0.902,0.903,0.905,0.909,0.913,0.912],
 		    "(C)":            [],
-		    "(omit)":         []
+		    "(omit)":         [],
+		    "(comment)": []
 		}	
 	    });
 	case 2:
@@ -458,7 +476,8 @@ function example(geochronometer,plotdevice,format){
 				       0.22,0.22,0.22,0.21,0.22,0.2,0.22,0.21,0.21,0.21,
 				       0.21,0.21,0.21,0.22,0.21,0.21,0.21,0.21,0.2,0.2],
 		    "(C)":            [],
-		    "(omit)":         []
+		    "(omit)":         [],
+		    "(comment)": []
 		}
 	    });
 	case 3:
@@ -495,7 +514,8 @@ function example(geochronometer,plotdevice,format){
 				       0.0462,0.0465,0.0449,0.0455,0.0462,0.0425,
 				       0.0425,0.0445,0.0437,0.0457,0.0481,0.0488],
 		    "(C)":            [],
-		    "(omit)":         []
+		    "(omit)":         [],
+		    "(comment)": []
 		}
 	    });
 	}
@@ -515,7 +535,8 @@ function example(geochronometer,plotdevice,format){
 		    "rhoXZ":  [0.724, 0.594, 0.516, 0.46, 0.421, 0.393],
 		    "rhoYZ":  [0.728, 0.597, 0.518, 0.462, 0.422, 0.394],
 		    "(C)":    [],
-		    "(omit)": []
+		    "(omit)": [],
+		    "(comment)": []
 		}	
 	    });
 	case 2:
@@ -532,7 +553,8 @@ function example(geochronometer,plotdevice,format){
 		    "rhoXZ":  [0.514, 0.6284, 0.6905, 0.7275, 0.7606, 0.7836],
 		    "rhoYZ":  [0.3348, 0.3182, 0.3043, 0.2972, 0.288, 0.2797],
 		    "(C)":    [],
-		    "(omit)": []
+		    "(omit)": [],
+		    "(comment)": []
 		}
 	    });
 	case 3:
@@ -545,7 +567,8 @@ function example(geochronometer,plotdevice,format){
 		    "err[0/2]": [0.114, 0.052, 0.034, 0.025, 0.021, 0.018],
 		    "(rho)":    [0.728, 0.597, 0.518, 0.462, 0.422, 0.394],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)": []
 		}	
 	    });
 	case 4:
@@ -558,7 +581,8 @@ function example(geochronometer,plotdevice,format){
 		    "err[0/8]": [0.0154, 0.0151, 0.015, 0.0146, 0.0148, 0.0149],
 		    "(rho)":    [0.3348, 0.3182, 0.3043, 0.2972, 0.288, 0.2797],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)": []
 		}
 	    });
 	}
@@ -582,7 +606,8 @@ function example(geochronometer,plotdevice,format){
 				       0.0001,0.0001,0.0001,0.0001,0.0001],
 		    "(rho)":          [],
 		    "(C)":            [],
-		    "(omit)":         []
+		    "(omit)":         [],
+		    "(comment)":      []
 		}	
 	    });
 	case 2:
@@ -605,7 +630,8 @@ function example(geochronometer,plotdevice,format){
 				       0.0049,0.0026,0.0023,0.0074,0.0057,0.0051,
 				       0.0034,0.0061,0.030,0.0303,0.0301],
 		    "(C)":            [],
-		    "(omit)":         []
+		    "(omit)":         [],
+		    "(comment)":      []
 		}	
 	    });
 	case 3:
@@ -627,7 +653,8 @@ function example(geochronometer,plotdevice,format){
 				   0.0001,0.0001,0.0001,0.0001,0.0001,0.0001,
 				   0.0001,0.0001,0.0001,0.0001,0.0001],
 		    "(C)":        [],
-		    "(omit)":     []
+		    "(omit)":     [],
+		    "(comment)":  []
 		}
 	    });
 	}
@@ -643,7 +670,8 @@ function example(geochronometer,plotdevice,format){
 		    "err[Nd143/Nd144]": [0.00006,0.00001,0.00002,0.00003],
 		    "(rho)":            [0.014,0.0023,0.0047,0.0058],
 		    "(C)":              [],
-		    "(omit)":           []
+		    "(omit)":           [],
+		    "(comment)":        []
 		}
 	    });
 	case 2:
@@ -656,7 +684,8 @@ function example(geochronometer,plotdevice,format){
 		    "err[Nd144/Nd143]": [0.000228,0.000038,0.000076,0.000113],
 		    "(rho)":            [0.095,0.017,0.034,0.051],
 		    "(C)":              [],
-		    "(omit)":           []
+		    "(omit)":           [],
+		    "(comment)":        []
 		}
 	    });
 	case 3:
@@ -670,7 +699,8 @@ function example(geochronometer,plotdevice,format){
 		    "143/144":      [0.51297,0.51417,0.51455,0.51545],
 		    "err[143/144]": [0.00006,0.00001,0.00002,0.000025],
 		    "(C)":          [],
-		    "(omit)":       []
+		    "(omit)":       [],
+		    "(comment)":    []
 		}
 	    });
 	}
@@ -689,7 +719,8 @@ function example(geochronometer,plotdevice,format){
 		    "(rho)":            [0.073,0.23,0.067,0.113,
 					 0.434,0.143,0.215,0.104],
 		    "(C)":              [],
-		    "(omit)":           []
+		    "(omit)":           [],
+		    "(comment)":        []
 		}
 	    });
 	case 2:
@@ -705,7 +736,8 @@ function example(geochronometer,plotdevice,format){
 					 0.00495,0.00067,0.00089,0.00065],
 		    "(rho)":            [0.33,0.77,0.32,0.35,0.87,0.4,0.53,0.28],
 		    "(C)":              [],
-		    "(omit)":           []
+		    "(omit)":           [],
+		    "(comment)":        []
 		}
 	    });
 	case 3:
@@ -723,7 +755,8 @@ function example(geochronometer,plotdevice,format){
 		    "err[187/188]": [0.0039,0.0064,0.0028,0.0054,
 				     0.0221,0.0046,0.0072,0.0052],
 		    "(C)":          [],
-		    "(omit)":       []
+		    "(omit)":       [],
+		    "(comment)":    []
 		}
 	    });
 	}
@@ -741,7 +774,8 @@ function example(geochronometer,plotdevice,format){
 					 0.000014,0.000016,0.000011],
 		    "(rho)":            [],
 		    "(C)":              [],
-		    "(omit)":           []
+		    "(omit)":           [],
+		    "(comment)":        []
 		}
 	    });
 	case 2:
@@ -754,7 +788,8 @@ function example(geochronometer,plotdevice,format){
 		    "err[Hf177/Hf176]": [0.00011,0.00022,0.0001,0.00016,0.00019,0.00013],
 		    "(rho)":            [0.004,0.0081,0.0037,0.0059,0.0069,0.0048],
 		    "(C)":              [],
-		    "(omit)":           []
+		    "(omit)":           [],
+		    "(comment)":        []
 		}
 	    });
 	case 3:
@@ -769,7 +804,8 @@ function example(geochronometer,plotdevice,format){
 		    "err[176/177]": [0.0000095,0.0000195,0.0000085,
 				     0.000014,0.0000155,0.000011],
 		    "(C)":          [],
-		    "(omit)":       []
+		    "(omit)":       [],
+		    "(comment)":    []
 		}
 	    });
 	}
@@ -790,7 +826,8 @@ function example(geochronometer,plotdevice,format){
 		"Sm":       [],
 		"err[Sm]":  [],
 		"(C)":      [],
-		"(omit)":   []
+		"(omit)":   [],
+		"(comment)": []
 	    }
 	});
     case 'fissiontracks':
@@ -807,7 +844,8 @@ function example(geochronometer,plotdevice,format){
 		    "Ni":     [132,187,565,51,122,249,159,50,80,79,217,152,231,
 			       347,75,135,186,123,61,107,135,43,215,52,165],
 		    "(C)":    [],
-		    "(omit)": []
+		    "(omit)": [],
+		    "(comment)": []
 		}
 	    });
 	case 2:
@@ -845,7 +883,8 @@ function example(geochronometer,plotdevice,format){
 		    "(U5)":      [],
 		    "(err[U5])": [],
 		    "(C)":       [],
-		    "(omit)":    []
+		    "(omit)":    [],
+		    "(comment)": []
 		}
 	    });
 	case 3:
@@ -878,7 +917,8 @@ function example(geochronometer,plotdevice,format){
 		    "(U5)":      [],
 		    "(err[U5])": [],
 		    "(C)":       [],
-		    "(omit)":    []
+		    "(omit)":    [],
+		    "(comment)": []
 		}
 	    });
 	}
@@ -896,7 +936,8 @@ function example(geochronometer,plotdevice,format){
 			"err[Y]":   [4.6,5.3,5.1,9.0,8.7,3.4],
 			"rXY":      [0.976,0.992,0.992,0.996,0.997,0.956],
 			"(C)":      [],
-			"(omit)":   []
+			"(omit)":   [],
+			"(comment)": []
 		    }
 		});
 	    case 5:
@@ -922,7 +963,8 @@ function example(geochronometer,plotdevice,format){
 				     0.75988506,0.88895174,0.89357971,1.52314302,
 				     1.45743969,0.55666518,0.51691077],
 			"(C)":      [],
-			"(omit)":   []
+			"(omit)":   [],
+			"(comment)": []
 		    }
 		});
 	    case 6:
@@ -979,7 +1021,8 @@ function example(geochronometer,plotdevice,format){
 			"s[,Y12]": [3.762E-11,4.393E-11,4.835E-11,4.602E-11,4.494E-11,3.645E-11,4.929E-11,3.474E-11,3.155E-11,3.811E-11,-1.273E-10,3.309E-10,
 				    1.315E-10,1.531E-10,1.681E-10,1.600E-10,1.566E-10,1.272E-10,1.716E-10,1.214E-10,1.101E-10,1.328E-10,3.514E-09,6.441E-09],
 			"(C)":     [],
-			"(omit)":  []
+			"(omit)":  [],
+			"(comment)": []
 		    }
 		});
 	    default:
@@ -996,7 +1039,8 @@ function example(geochronometer,plotdevice,format){
 		    "err[X]":   [0.9350,0.1225,0.0964,0.0861,0.0776,0.0734,0.0717,
 				 0.0677,0.0134,0.0388,0.0246,0.0207,0.0472,0.1952],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)": []
 		}
 	    });
 	case 'radial':
@@ -1014,7 +1058,8 @@ function example(geochronometer,plotdevice,format){
 				 8.05,10.45,8.75,9.1,9.1,11.2,11.3,14.8,12.25,14.15,
 				 14.5,15.4,27.7,31.45],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)": []
 		}
 	    });
 	case 'average':
@@ -1029,7 +1074,8 @@ function example(geochronometer,plotdevice,format){
 				 2.119,1.770,2.682,1.147,1.910,2.258,2.011,1.361,2.900,
 				 1.687,2.251,2.723,1.582,2.986,2.064,2.878,1.068,1.509,1.159],
 		    "(C)":      [],
-		    "(omit)":   []
+		    "(omit)":   [],
+		    "(comment)": []
 		}
 	    });
 	case 'KDE':
@@ -1042,7 +1088,8 @@ function example(geochronometer,plotdevice,format){
 			       253.917,252.467,243.340,249.719,247.279,249.823,248.678,
 			       252.541,252.728,254.567,249.526,249.276,250.957,260.903,
 			       259.126,250.055,251.202,250.970,249.655,260.678],
-		    "(omit)": []
+		    "(omit)": [],
+		    "(comment)": []
 		}
 	    });
 	}
@@ -1211,3 +1258,4 @@ function example(geochronometer,plotdevice,format){
     default:
     }
 }
+
